%% MT Homogenization 3.0 - spherical inclusions with coated particles (05/05/2012)
% created by Vaclav Nezerka

addpath(fullfile(pwd,'files'))
addpath(fullfile(pwd,'functions'))
addpath(fullfile(pwd,['functions' filesep 'stiffness constants']))
addpath(fullfile(pwd,'input'))

%% Loading

sigma = [1;0;0;0;0;0]; % macroscopic strain on the sample

%% Calculation

run input_processing

[K_eff G_eff] = f_MT_incl_coated(...
	c_matrix, c_uncoated, c_coated, c_coating,...
	K_matrix, K_uncoated, K_coated, K_coating,... 
	G_matrix, G_uncoated, G_coated, G_coating,...
	r_coated, r_coating);

[E_eff nu_eff] = f_E_and_nu_from_K_and_G(K_eff,G_eff);
L_eff = f_L_from_K_and_G(K_eff,G_eff);
    
%% Numerical differentiation of Lr with respect ot Gr
    
G_full = [G_matrix; G_uncoated; G_coated; G_coating];
c_full = [c_matrix; c_uncoated; c_coated; c_coating];
n_full = size(G_full,1);
n_uncoated = size(G_uncoated,1);
n_coated = size(G_coated,1);
    
dL_eff = zeros(6,6,n_full);
    
for n = 1:n_full
	dG_full = G_full;
	dG_full(n) = G_full(n)+1; % increase the shear modulus by 1
        
	dG_matrix = dG_full(1);
	dG_uncoated = dG_full(2:1+n_uncoated);
	dG_coated = dG_full(2+n_uncoated:1+n_uncoated+n_coated);
	dG_coating = dG_full(2+n_uncoated+n_coated:1+n_uncoated+2*n_coated);

    %% Mori-Tanaka homogenization of modified inclusions (dG)

	[dK_eff dG_eff] = f_MT_incl_coated(...
        c_matrix, c_uncoated, c_coated, c_coating,...
        K_matrix, K_uncoated, K_coated, K_coating,... 
        dG_matrix, dG_uncoated, dG_coated, dG_coating,...
        r_coated, r_coating);
        
	dL_eff_r = f_L_from_K_and_G(dK_eff,dG_eff);
	dL_eff(:,:,n) = (dL_eff_r-L_eff)/1; % (L(G+100)-L(G))/100
	end

%% Determination of deviatoric stress averages

E = L_eff\sigma;
e_dev_coated = zeros(n_full,1);  % vector w/ deviatoric strain averages
for i = 1:n_full
	e_dev_coated(i) = sqrt(1/(4*c_full(i))*E'*dL_eff(:,:,i)*E);
end

s_dev = 2*G_full.*e_dev_coated;    % vector w/ deviatoric stress averages

%fprintf('\n %s :\n', input_name)
%fprintf('\nE_eff = %.1f MPa\n', E_eff/1e6)
%fprintf('nu_eff = %.3f\n', nu_eff)
%fprintf('deviatoric stress in matrix = %.3f\n', s_dev(1))